#
# spec file for package ostree
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ostree
Version:        2016.6
Release:        1.3
Summary:        Git for operating system binaries
License:        GPL-2.0+
Group:          System/Libraries
Url:            https://github.com/ostreedev/ostree
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE ostree-grub2-location.patch boo#974714 dimstar@opensuse.org -- Fix path to grub-mkconfig_lib
Patch0:         ostree-grub2-location.patch
BuildRequires:  bison
BuildRequires:  gjs
BuildRequires:  gnome-common
BuildRequires:  gobject-introspection-devel >= 1.34.0
BuildRequires:  gpgme-devel
BuildRequires:  libattr-devel
BuildRequires:  libcap-devel
BuildRequires:  pkgconfig(e2p)
BuildRequires:  pkgconfig(fuse) >= 2.9.2
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.36.0
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libgsystem) >= 2015.1
BuildRequires:  pkgconfig(liblzma) >= 5.0.5
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.39.1
BuildRequires:  pkgconfig(mount) >= 2-23.0
BuildRequires:  pkgconfig(systemd)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n libostree-1-1
Summary:        Git for operating system binaries
Group:          System/Libraries

%description -n libostree-1-1
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n typelib-1_0-OSTree-1_0
Summary:        Git for operating system binaries  -- GObject bindings
Group:          System/Libraries

%description -n typelib-1_0-OSTree-1_0
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%ifnarch s390 s390x %{arm}
%package        grub2
Summary:        GRUB2 integration for OSTree
Group:          Development/Libraries
%ifnarch aarch64
Requires:       grub2
%else
Requires:       grub2-efi
%endif

%description grub2
GRUB2 integration for OSTree
%endif

%package devel
Summary:        Git for operating system binaries -- Development files
Group:          Development/Languages/C and C++
Requires:       libostree-1-1 = %{version}
Requires:       typelib-1_0-OSTree-1_0 = %{version}

%description devel
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure --with-dracut
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

# openSUSE rcFOO links
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcostree-prepare-root
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcostree-remount

%post -n libostree-1-1 -p /sbin/ldconfig

%postun -n libostree-1-1 -p /sbin/ldconfig

%pre
%service_add_pre ostree-prepare-root.service
%service_add_pre ostree-remount.service

%preun
%service_del_preun ostree-prepare-root.service
%service_del_preun ostree-remount.service.service

%post
%service_add_post ostree-prepare-root.service
%service_add_post ostree-remount.service

%postun
%service_del_postun ostree-prepare-root.service
%service_del_postun ostree-remount.service

%files
%defattr(-,root,root)
%doc README.md COPYING
%{_mandir}/man1/ostree*.1%{?ext_man}
%{_mandir}/man5/ostree.repo*.5%{?ext_man}
%{_mandir}/man1/rofiles-fuse.1%{?ext_man}
%{_bindir}/ostree
%{_bindir}/rofiles-fuse
%{_libexecdir}/ostree/
%{_sbindir}/ostree-prepare-root
%{_sbindir}/ostree-remount
%dir %{_libexecdir}/dracut
%dir %{_libexecdir}/dracut/modules.d
%{_libexecdir}/dracut/modules.d/98ostree/
%{_unitdir}/ostree-prepare-root.service
%{_unitdir}/ostree-remount.service
%dir %{_sysconfdir}/dracut.conf.d
%{_sysconfdir}/dracut.conf.d/ostree.conf
%{_datadir}/ostree/
%{_sbindir}/rcostree-prepare-root
%{_sbindir}/rcostree-remount
%exclude %{_sysconfdir}/grub.d/*ostree
%exclude %{_libexecdir}/ostree/grub2*

%files -n libostree-1-1
%defattr(-,root,root)
%{_libdir}/libostree-1.so.*

%files -n typelib-1_0-OSTree-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/OSTree-1.0.typelib

%files devel
%defattr(-,root,root)
%{_includedir}/ostree-1/
%{_libdir}/libostree-1.so
%{_libdir}/pkgconfig/ostree-1.pc
%{_datadir}/gir-1.0/OSTree-1.0.gir

%ifnarch s390 s390x %{arm}
%files grub2
%dir %{_sysconfdir}/grub.d/
%{_sysconfdir}/grub.d/*ostree
%{_libexecdir}/ostree/grub2*
%endif

%changelog
* Tue Jun 28 2016 fcrozat@suse.com
- Move grub2 related files to new ostree-grub2 subpackage (similar
  to Fedora), only used to integrate ostree with grub2
  (fully fix boo#974714).
* Mon Jun 27 2016 fcrozat@suse.com
- Update to version 2016.6:
  + refs: add "ostree refs --create" and unit tests.
  + manual: Link to mender.io.
  + Add "archive" as an alias for "archive-z2".
  + libglnx porting: delete temp files on failure of file creation.
  + repo: Avoid a possible divide by zero in progress.
  + manual: Discuss mirroring.
  + build: Fix libreaddir-rand to honor global CFLAGS.
  + tests: Support OT_SKIP_READDIR_RAND.
  + pull: Ensure we always process queue only from main thread.
- Switch git url to https://github.com/ostreedev/ostree.
- Fix Url in specfile.
* Wed May 11 2016 dimstar@opensuse.org
- Add ostree-grub2-location.patch: Fix path to find
  grub-mkconfig_lib. openSUSE installs those files to
  /usr/share/grub2, upstream would do /usr/share/grub (boo#974714).
* Fri Apr 22 2016 zaitor@opensuse.org
- Update to version 2016.5:
  + Add a stub .travis.yml.
  + tests: Add a test-abi.
  + pull: Add OSTREE_REPO_PULL_FLAGS_UNTRUSTED flag.
  + Add --untrusted option to pull and pull-local.
  + OstreeSePolicy: add ostree_sepolicy_get_csum().
  + core: Add verbose messages for pruning.
  + core: Add debug messages for traversing.
  + build: Set G_LOG_DOMAIN to OSTree.
  + main: Set log handler for OSTree domain.
  + packaging: fix bashism in dist-snapshot target.
  + docs: Add a section on repository management.
  + commit: Support generating commits with no parent, or a custom
    one.
  + commit: Support writing orphans.
  + commit: support editor for orphan commits.
  + docs/CONTRIBUTING.md: Update for github move, Homu etc.
  + test-xattrs: use TAP syntax to skip test.
  + various tests: skip if temp directory lacks xattr support.
  + Symlink libreaddir-rand.so into tests directory.
  + tap-test: clean up temporary test directories as intended.
  + In tests that use gpg, terminate the gpg-agent after testing.
  + Load g-i bindings from builddir during build-time testing.
  + tests/admin-test.sh: this is a bash script, not a POSIX sh
    script.
  + Force libreaddir-rand to be a shared library.
  + Skip tests that run rofiles-fuse if /dev/fuse or /etc/mtab
    unavailable.
  + test-pull-untrusted.sh: always corrupt a regular file, not a
    symlink.
  + basic-test: commit with a non-empty subject.
  + Probe for GNU parallel more accurately.
  + tests: Make failing to kill the GPG agent non-fatal.
  + libtest.sh: use G_TEST_SRCDIR, G_TEST_BUILDDIR to find
    resources.
  + test-abi: use G_TEST_SRCDIR, G_TEST_BUILDDIR.
  + test-xattrs: sync how this is skipped with test-rofiles-fuse.
  + libtest.sh: only check whether $(pwd) is empty once.
  + manual: Fix a bunch of typos and docbookisms.
  + Introducing ostree-grub-generator.
  + pull: Don't try to cache summaries for pull-local.
  + Fix local-pull test.
  + pull-local: Support --gpg-verify and --gpg-verify-summary.
  + build: Find grub2-mkconfig a bit more automagically.
  + build: Make tests/libreaddir-rand.so rule use AM_V_GEN.
  + tests: add libostreetest.h to EXTRA_DIST.
  + tests: add missing ${CMD_PREFIX} before ostree.
  + contrib: indent golang code using only tabs instead of both
    tabs and spaces.
  + Remove empty new lines at the EOF.
  + docs: Prefer the form "cannot" to "can not".
  + Use git.mk.
  + Support pathnames for --subpath=...
  + Export ostree_repo_get_remote_option* functions.
  + Inherit remotes and remote options from parent repo.
  + Add test case for inheriting remote options.
  + cfg.mk: ignore syntax-check for git.mk.
  + Add support for ostree static-delta delete.
  + small cleanups.
  + Fix the symbol versions for ostree_repo_get_remote_*option.
  + ostree-repo-pull: always initialize flags_i.
  + pull: More consistently use remote_repo_local for local repos.
  + build: Move grub2-15_ostree back to pkglibexecdir.
  + Fix AS_HELP_STRING for builtin grub2 mkconfig.
  + fetcher: Initialize output_stream_set_lock mutex.
  + commit: Fix crash if dfd_iter is NULL.
  + Add cache_dir_fd to OstreeRepo.
  + Add OstreeRepo option for an out-of-band cache dir.
  + man: Elaborate on per-remote GPG.
  + Add remotes-config-dir to OstreeRepo.
  + Look for $remotename.trustedkeys.gpg in remotes.d dir.
  + refs: Add g_prefix_error around opendir for easier debugging.
  + static-delta: Put temp files in /var/tmp.
  + static-delta: Initialize read_source_fd to -1.
- Stop passing --with-grub2 to configure, no longer recognized.
* Mon Apr 11 2016 zaitor@opensuse.org
- Update to version 2016.4:
  + fetcher: Remove message_to_request table
  + fetcher: Convert from GSimpleAsyncResult to GTask
  + fetcher: Rework reference counting
  + fetcher: Track outstanding requests with a table
  + sysroot: Cleanup refs and prune even on last undeployment
  + pull: Recover from missing commits in recursive pulls
  + doc: Note that refs --delete does not prune
  + tests: Add a test for pull+deploy of specific "bare" commit
  + static-delta: Handle LZMA_BUF_ERROR returned by zlib
  + static-delta: Don't run bspatch when output object already
    exists
  + static-delta: Set error on bsdiff failure
  + commit: Improve variable name
  + Don't require /boot/uEnv.txt for u-boot support
  + tests: fix LZMA test to really compress/decompress
  + upgrader: Add ostree_sysroot_upgrader_dup_origin()
  + upgrader: Allow overriding the commit to pull
  + upgrade: Add --override-commit=CHECKSUM option
  + prepare-root: set up /boot bind-mount for single partition
    systems
  + static-delta: Fix annotation on
    ostree_repo_list_static_delta_names
  + sysroot: Write symlinks before calling fsync(), then rename
    after
  + init-fs: Explicitly set /tmp to 01777
  + core: use OSTREE_OBJECT_TYPE_LAST instead of
    OSTREE_OBJECT_TYPE_COMMIT
  + pull: add support for tombstone commits
  + repo: create a tombstone commit when deleting a commit
  + fsck: add argument --add-tombstones
  + tests: add tests for prune and tombstones commits
  + docs: Note not to put private keys in /usr/share/ostree
  + generate-static-delta: Support min-fallback-size 0 to disable
    fallbacks
  + static deltas: Add support for inline-parts
  + static-deltas generate: Add --inline option to CLI tool
  + Add tests for inline static deltas
  + deltas: Make apply-offline only read the parts once
  + delta: Ensure the from commit exists when applying static delta
  + static-delta apply-offline: Don't skip validation
  + Add _ostree_repo_open|commit_untrusted_content_bare
  + deltas: Verify checksums in apply-offline unless skip_validate
    is TRUE
  + deltas: Make min-fallback-size 0 actually disable fallbacks
  + deltas: Support passing filename to delta generator
  + deltas: Support passing filename to
    ostree_repo_static_delta_execute_offline
  + pull: Verify checksums from static deltas unless gpg signed
    summary
  + deltas: Support including detached metadata in static deltas
  + libostree: Fix a couple compiler warnings
  + prune: add --delete-commit
  + fsck: create a tombstone when the parent is missing
  + tests: add test for ostree prune --delete-commit
  + prune: add --keep-younger-than=DATE
  + pull: make slightly clearer when failing for missing xattrs
    support
  + ostree: do not print the usage on each G_IO_ERROR_NOT_SUPPORTED
  + libostree: add new API ostree_repo_write_commit_with_time
  + commit: add --timestamp=TIMESTAMP
  + tests: add tests for prune --keep-younger-than=DATE
  + tests: prefix invocation of ostree with  where missing
  + repo: Validate checksums have correct length
  + repo: Never delete .commitmeta files
  + trivial-httpd: Avoid SoupBuffer when there's no content
  + glnx: Update from master
  + fetcher: Remove "sending_messages" hash table
  + fetcher: Remove "total_requests" counter
  + remote: Print full refspec in "ostree remote refs"
  + repo: Fix backwards timestamp in ostree_repo_write_commit()
  + gpg-verifier: Fix compiler warning
  + Release 2015.11
  + parse-datetime: use the module from gnulib
  + tests: add missing ${CMD_PREFIX}
  + cmdline: Fatally error if the timestamp in a commit is invalid
  + build: Delete generated parse-datetime.c file, use AM_V_GEN
  + build: Also add a configure check for YACC/bison
  + Update to latest libglnx
  + repo: Add _ostree_repo_allocate_tmpdir helper
  + repo: Use per-transaction staging dir
  + repo: Allocate a tmpdir for each OstreeFetcher to isolate
    concurrent downloads
  + fetcher: Add "config-flags" construct-only property
  + fetcher: Move the SoupSession to a separate thread
  + pull: Push a temporary main context for sync requests
  + build: Fix srcdir != builddir
  + repo: Add ostree_repo_verify_summary()
  + remote: Add "ostree remote summary" command
  + repo: new function ostree_repo_prune_static_deltas
  + prune: add new flag --static-deltas-only
  + tests: add tests for prune --static-deltas-only
  + deploy: Find kernel/initramfs consistently from filesystem
  + bootconfig: Add ostree_bootconfig_parser_write_at
  + deploy: Change large parts to be fd-relative, drop fsync
  + fetcher: Lazily create tmp directory
  + grub2_generate: load sysroot before using it
  + repo: Expose dfd-relative mtree writes as public API
  + repo: Add APIs for devino optimization between checkout ->
    commit
  + Release 2016.1
  + repo: Note global transaction resume is legacy
  + sysroot: Don't individually fsync dirs in checkout, rely on
    syncfs
  + diff: do not traverse parent commits
  + Add a checkout option to skip fsync
  + refs: Add a missing `goto out` for error handling
  + grub2: Don't delete grub2.cfg.old file we just copied
  + tests: Use "bash strict mode"
  + build: Move man pages into man/
  + build: Rename doc/ -> apidoc/
  + Rewrite manual in mkdocs
  + apidoc: Remove unnecessary srcdir != builddir workaround
  + repo: Port -refs.c to openat()
  + build: Add --disable-man
  + lib: Add a #define OSTREE_SHA256_DIGEST_LEN 32
  + build: Hoist man conditional higher
  + static-delta: Add `show` subcommand
  + packaging: Sync spec file with Fedora
  + build: 'make clean' removes parse-datetime.c
  + docs-md: Delete (obsoleted by docs/)
  + README.md: Update to link to Read The Docs, describe a bit
    better
  + build: Remove --disable-static-deltas option
  + lib: Create an internal static delta parsing/opening function
  + lib: Expand `ostree static-delta show` to show part stats
  + fetcher: Fix hung GTlsInteraction
  + Import rofiles-fuse
  + Add an `export` builtin, and API to write to libarchive
  + pull: Support specifying exact commit to pull via branch@commit
  + manual-tests: New static-delta-generate-crosscheck.sh
  + man/ostree-export.xml: Add to git
  + Support Docker-style whiteouts
  + packaging: Add a fuse subpackage
  + rofiles-fuse: Fix truncate call to not use O_CREAT
  + manual: Note that the bare-user mode exists
  + Rename libarchive write API to "export", matching command line
  + repo: Add ostree_repo_import_archive_to_mtree
  + ostree-sysroot: add debug option to help testing
  + pull: Add require-static-deltas pull option
  + pull: Add a --dry-run option for static deltas
  + build: Link ostree with libarchive
  + docs: Add a new formats section, move static deltas in there
  + libarchive: Make autocreate_parents imply autocreating root dir
  + build: Use threadsafe GPGME
  + gpg: Use gpg_strerror_r for threadsafety
  + Release 2016.2
  + libarchive: Fix a 32 bit format warning
  + lib: Two more compiler warning fixes
  + deltas: Fix some more 32 bit warnings
  + deltas: Fix regression in
    ostree_repo_static_delta_execute_offline
  + rofiles-fuse: Handle operations on the root
  + deltas: Include an endianness marker
  + deltas: Use endianness marker when parsing
  + deltas: Heuristically detect endianness for older deltas
  + deltas: Add a compression size heuristic for endianness
    detection
  + Release 2016.3
  + docs: Add a blurb on the summary file
  + Fix make syntax-check
  + test-rofiles-fuse: skip when fusermount is not present
  + lib: Introduce versioned symbols
  + repo: Add ostree_repo_get_dfd()
  + Add a missing #include to fix "make check"
  + ostree-repo: new public function `ostree_repo_list_refs_ext`
  + refs: allow to specify multiple refs as args
  + refs: add tests
  + libostree: Adjust `cleanup_ref_prefix` to use
    ostree_repo_list_refs_ext
  + refs: Add argument --list to print the full ref name
  + tests: Port to glib-tap.mk, make `make check` run all of the
    tests
  + deploy: Bump the mtime on ostree/deploy after deployments
    finish
  + tests: Convert two more exit 77 instances into TAP-compatible
    SKIP
  + docs/introduction: Note VMs vs baremetal
  + lib: Add ostree_sysroot_init_osname() API, bump mtime
  + tests: More TAP fixups
  + tests: Unify some tmpdir code, add ability for C to use
    libtest.sh
  + lib: Add ostree_sysroot_load_if_changed() API
  + tests/basic: Fix race in timestamp test
  + build: Don't install test data without --enable-installed-tests
  + docs: Reference the git docs on references
  + libotutil: new function ot_openat_ignore_enoent
  + pull: cache summary and summary.sig
  + repo: use the skip summary download optimization for
    repo_remote_fetch_summary
  + prune: delete all cached summaries files
  + tests: add test for summary file caching
  + repo: Fix the skip-summary-if-summary.sig-is-same cache
  + rofiles-fuse: Fix permission comparison
  + docs: Cleanup Markdown
  + docs: Add a section on writing buildsystems
  + contrib/golang: Initial golang bindings
  + tests: Strengthen test tmpdir sanity check, be compat with
    ginsttest saving
  + libglnx porting: gs_fd_close -> glnx_fd_close
  + libglnx porting: gs_free -> g_autofree
  + libglnx porting: xattr calls
  + libglnx porting: gs_transfer_out_value -> g_steal_pointer
  + Don't fail "ostree remote refs" if writing the summary cache is
    not permitted
  + manual: Migrate related projects wiki page into manual
  + deploy: Handle a read-only /boot
  + mkdocs: Fix the site name
  + tests/admin-test.sh: add #!/bin/sh
  + Skip test_libarchive_ignore_device_file if we cannot write
    xattrs
  + test-libarchive: fix underlinking
  + admin-switch: Add missing reboot argument
  + Use GSubprocess instead of GSSubprocess (libgsystem removal)
  + libglnx porting: Use glnx_set_error_from_errno
  + libglnx porting: Use glnx_shutil_rm_rf_at()
  + libglnx porting: Use glnx_opendirat()
  + admin: Add an `unlock` command, and libostree API
  + Fix building without libarchive
  + pull local: Don't import objects we already have
  + prune: Don't fail on partial commits
  + tests: Add a commitpartial + prune test
  + traverse: Require variant when traversing dirtree
  + Release 2016.4
- Add bison, pkgconfig(fuse) and pkgconfig(mount) BuildRequires:
  New dependencies.
* Thu Oct  8 2015 zaitor@opensuse.org
- Update to version 2015.9:
  + _ostree_static_delta_part_validate: Take a stream instead of a
    file as arg
  + sysroot: Add ostree_sysroot_prepare_cleanup()
  + deploy: Do not prune repository
  + libglnx: Update from master
  + reset: Simplify argument checking logic
  + repo: Fix build without libsoup
  + pull: Honor depth with OSTREE_REPO_PULL_FLAGS_COMMIT_ONLY
  + Mutable is a keyword in C++11
  + Remove unused variables
* Thu Oct  8 2015 zaitor@opensuse.org
- Update to version 2015.8:
  + gpg: Add ostree_gpg_verify_result_describe()
  + admin: Show GPG signatures in status command
  + pull-metalink: Don't print error output when we expect failure
  + Add an API to set/unset a deployment tree's mutability
  + ostree_repo_checkout_tree_at: remove @subpath documentation
  + refs: Use *at for writes, honor repo fsync flag
  + repo: Add a private helper to replace a file, honoring fsync
    policy
  + libglnx: Pick up file permission regression fix
  + tests: Fix root uid check in test-commit-sign.sh
  + _ostree_repo_file_replace_contents: make buf const
  + summary: write the contents to a temporary file
  + config: add new parameter "commit-update-summary" to core
    section
  + libglnx: Update to latest
  + reset: Don't enforce parent commits
  + repo: Improve error handling in sign_data()
  + repo: Add a "gpg-verify-result" signal
  + pull: Print GPG signature status as soon as its known
  + repo: Add ostree_repo_remote_get_gpg_verify()
  + admin: Conditionally show GPG signatures in status command
  + sysroot: Cache an OstreeRepo instance
  + main: Tweak GPG output to match rpm-ostree
  + sysroot: Add ostree_sysroot_get_fd()
  + libglnx: Update from master
  + sysroot: Close sysroot fd in finalize
  + status: Don't crash if we deployed a local refspec
  + deploy: Use syncfs() in addition to sync()
  + deploy: Drop fsync of modified config files
  + deploy: Drop a fsync, use fd-relative APIs
  + README.md: fix typo
  + reset: update help output
  + pull: Always request detached metadata for commits
  + test-auto-summary.sh properly quote arguments to assert_streq
  + g_output_stream_splice: check correctly the error code
  + gpg: do not use secring.gpg
  + show: add option --gpg-homedir
  + libotutil: Establish a place for GPG utilities
  + libotutil: Add ot_gpgme_ctx_tmp_home_dir()
  + repo: Initialize GPGME in instance init()
  + ostree: Split up "remote" subcommands
  + gpg: Fix _ostree_gpg_verifier_add_keyring()
  + pull: the commit size in the summary is not for the detached
    metadata
  + Fix build when using GLib < 2.44
  + sysroot: Add an API to lock
  + libglnx: fix reference to commit
  + repo: Fix an obvious typo
  + doc: remove unknown parameter from inline documentation
  + core: Cleanup commitpartial file with fd-relative lookups
  + Teach fsck about partial commits
  + libglnx: Pick up bugfix and backports
  + repo: Stop creating "transaction" symlink
  + gpg: Add ostree_gpg_verify_result_describe_variant()
  + Juggling libglnx.h includes
  + Use g_autofree instead of gs_free
  + Use g_autoptr() for GIO object types
  + Use glnx_unref_object instead of gs_unref_object
  + Use g_autoptr(GChecksum) instead of gs_free_checksum
  + Use g_autoptr(GBytes) instead of gs_unref_bytes
  + Use g_autoptr(GHashTable) instead of gs_unref_hashtable
  + Use g_autoptr(GPtrArray) instead of gs_unref_ptrarray
  + Use g_autoptr(GVariant) instead of gs_unref_variant
  + Use g_autoptr(GKeyFile) instead of gs_unref_keyfile
  + Use g_autoptr(GVariantBuilder) instead of
    gs_unref_variant_builder
  + Use g_auto(GStrv) instead of gs_strfreev
  + Remove unnecessary #include "libgsystem.h"
  + trivial-httpd: fix indentation
  + trivial-httpd: add option to specify the port
  + summary: list the available static deltas
  + core: new function _ostree_parse_delta_name
  + core: store information about delta files checksums
  + pull: check that the superblock checksum is the same as in the
    summary
  + pull: get rid of detached metadata for deltas
  + ostree-repo: add new API to sign the summary file
  + summary: add new command line arguments to sign the summary
    file
  + pull: verify signature for the summary file
  + tests: add a test for signed summary file
  + summary: delete summary.sig on an update
  + ot-fs-utils: remove empty line at EOF
  + gpg: Fix ot_gpgme_error_to_gio_error()
  + gpg: Add custom data buffers to wrapper GIO streams
  + repo: Simplify sign_data() a little
  + sysroot: Add a try_lock() API
  + ostree-repo-pull: add option to disable static-deltas
  + pull: add new switch option --disable-static-deltas
  + doc: add missing options block for pull
  + tests: add new test for pull --disable-static-deltas
  + syntax-check: add syntactic rule to prohibit gs_unref_*
  + syntax-check: add syntactic rule to prohibit gs_strfreev
  + maint.mk: Remove GNU releases specific bits
  + repo: Stash keyring name in OstreeRemote
  + repo: Delete a remote's keyring when deleting a remote
  + repo: Add ostree_repo_remote_gpg_import()
  + repo: Add remote's keyring during GPG verification
  + ostree: Add a "remote gpg-import" command
  + ostree: Add --gpg-import to the "remote add" command
  + tests: Add test-remote-gpg-import.sh
  + admin: Use locking for most sysroot commands
  + tests: Fix writable repo test
  + test-basic: Always chown back before doing assertion
  + ostree-repo: replace more gs_unref_(variant|bytes) with
    g_autoptr
  + repo: Bump mtime any time we write a ref
  + repo: Prevent GPG keys from being imported to keybox format
  + admin: Ensure instutil commands and usage help don't grab lock
  + ostree-repo: document
    OSTREE_REPO_COMMIT_MODIFIER_FLAGS_GENERATE_SIZES
  + Fix annotations on ostree_repo_remote_gpg_import().
  + sysroot: Sort returned boot loader configs
  + tests: Add a test script to cross-check loader config vs GRUB2
  + tests: Add a crosscheck for syslinux bootloader config
    generation
  + tests: Run all tests through a randomized readdir()
  + pull: Ensure console state for multiple GPG verification
    messages
  + pull: Validate delta checksums more strongly
  + tests: Add a commented out test for mirroring with deltas
  + repo: Don't crash when creating a summary if we have --empty
    deltas
  + tests: Add a test-pull-summary-sigs
  + Revert "tests: Run all tests through a randomized readdir()"
  + tests: Run all tests through a randomized readdir()
  + tests/remote-gpg-import: Only commit workdir
  + gpg: Gracefully handle no trusted.gpg.d directory
  + Fix tests on 32 bit systems
  + tests: Link test-gpg-verify-result with gpgme
  + tests: Use readdir64 when _FILE_OFFSET_BITS set
  + tests: Use temporary gpg homedir
  + Revert "tests: skip test-commit-sign.sh when not root"
  + Fix double free in ostree_repo_pull_with_options
  + repo: Change GPG verification policy
  + autogen.sh: fix typo
  + tests/test-pull-mirror-summary.sh: remove empty newline
  + pull-local: Support --depth option
  + metalink: Fix behavior when requested file is not found
  + tests/metalink: Add a case with nested unknown elements
  + diff: Fix adding CLI options twice
  + repo: Add _ostree_repo_remote_new_fetcher()
  + repo: Add _ostree_repo_get_remote_option_inherit()
  + repo: Handle "file" remotes in
    ostree_repo_remote_get_gpg_verify()
  + repo: Redo ostree_repo_remote_get_url()
  + metalink: Allow NULL for "out" params in metalink requests
  + metalink: Return requested file as a GBytes
  + repo: Add ostree_repo_remote_fetch_summary()
  + ostree: Add a "remote refs" command
  + pull: verify summary signatures also when not mirroring
  + repo: new function ostree_repo_remote_get_gpg_verify_summary
  + pull: fail if GPG is enabled and the summary is not signed
  + tests: add test for check for remote add
  - -set=gpg-verify-summary=true
  + ostree_repo_remote_fetch_summary: honor gpg-verify-summary
  + pull: Error if gpg=true and summary is 404, add more tests
  + core: Fix inverted conditional in GPG checking
  + pull: Also fix misplaced remote name handling
  + tests: Check error messages instead of "expected-fail", handle
    old parallel
  + build: Make gtk-doc optional
  + pull: Avoid leaking signal handlers across fetch requests
  + pull: Plug a memory leak
  + core: Add _ostree_get_default_sysroot_path()
  + sysroot: Use _ostree_get_default_sysroot_path()
  + repo: Add a "sysroot-path" property
  + sysroot: Pass the internal repo a system root path
  + repo: Fix location of remote configs for system repos
  + main: Fix UID check based on sysroot path
  + tests: Export OSTREE_SYSROOT in setup_os_repository
  + tests: do not commit from the working directory
  + libostree: new API ostree_repo_remote_list_refs
  + repo: merge repo_remote_fetch_summary_{metalink,url}
  + repo: new function _ostree_preload_metadata_file
  + pull: new option --commit-metadata-only
  + static-delta: do not fail compilation with big files
  + static-delta: add max-bsdiff-size option
  + repo: fix an incorrect comment
  + repo: don't forget to abort the transaction when failed
  + Update .gitignore
  + README: Attempt to flesh out more, start moving docs from wiki
  + tests: add tests for --disable-bsdiff and --max-bsdiff-size
  + tests: skip tests using gjs/parallel if they are not installed
  + Update .gitignore
  + tests: add tests for LZMA compressor and decompressor
  + sysroot: Add an unload() API
  + pull: Stop using GMainLoop
  + tests: rename test-rollsum to test-rollsum-cli
  + rollsum: Fix assertion for CRC matches
  + tests: Add tests for rollsum
  + repo-pull: Add a queue for scanning
  + Update .gitignore
  + tests: Build test-lzma with LZMA flags
  + static-delta: Ignore symlinks when computing similar objects
  + static-delta: assert on non-regular files
* Sun Aug  9 2015 fcrozat@suse.com
- Update to version 2015.7:
  + critical update for v2015.4: fix a bug causing unpredictable
    ordering of generated syslinux/uboot/grub2 bootloader entries.
  + Performance enhancement for deployments; rely on syncfs()
    rather than individual fsync() calls.
  + GPG: Always retrieve detached metadata, so we'll find newly
    added signatures.
  + GPG: Support for keys specific to remotes, rather than relying
    on the global /usr/share/ostree/trusted.gpg.d
  + A new locking API (used for the commandline) so that concurrent
    invocations of e.g. `ostree admin upgrade` are safe.
  + Other enhancements targeted for the Cockpit program and
    rpm-ostree.
  + The summary file can now be GPG signed as well (preview).
  + Other changes to static deltas, which continue to evolve.
* Wed Apr  8 2015 dimstar@opensuse.org
- Update to version 2015.5:
  + pull: (trivial) Fix English in function name.
  + Fix make distcheck.
  + Fix repeated words.
  + Add infrastructure for "make syntax-check".
  + Remove trailing dot from error message.
  + syntax-check: quote the first argument to AC_DEFINE.
  + Remove unused include <assert.h>.
  + Remove unused <dirent.h>.
  + Remove magic argument numbers to exit(2).
  + Do not interleave spaces and tabs.
  + Replace "==" with "=" in shell script test.
  + pull: use a single per-transaction syncfs instead of fsync.
  + syntax-check: Remove empty lines at the end of file.
  + tests: Move test-varint and test-rollsum under "make check".
  + configure.ac: Enable option subdir-objects for automake.
  + tests: Add tests for ot-unix-utils.
  + packaging: Add man5 pages.
  + prepare-root: avoid double-stacked /sysroot mount.
  + prepare-root: Update comments.
  + repo: Hold an fd "repo_dir_fd" open for the toplevel too.
  + util: Add an API to atomic-replace a file, dirfd relative,
    optional fsync.
  + Add an internal API to stream content objects.
  + When mirroring, write content directly, do not verify.
  + pull: Copy the upstream summary file when doing a pull
  - -mirror.
  + Add an internal API to get a read fd for a content object.
  + pull: Optimize file:/// URIs to skip libsoup and hardlink if
    possible.
  + Change pull-local to just be a wrapper for pull with file:///.
  + pull-local: Fix regression with absolute paths.
  + repo: Fix major performance regression with --scan-hardlinks.
  + repo: Store pending objects in prefixed subdirectory.
  + deltas: Use base64 for csums, add version to parts.
  + deltas: Remove support for gzipped delta parts.
  + deltas: Add _V0 to part #define.
  + deltas: Rework format to allow streaming.
  + deltas: Compute rollsum targets.
  + deltas: Print total size of rollsums we would use.
  + deltas: Stub out a few more opcodes.
  + deltas: Use the new internal streaming APIs.
  + deltas: Flesh out the open/write/close opcodes.
  + deltas: Initial code to copy content from existing objects.
  + deltas: Implement rollsums.
  + deltas: Make syntax-check happy.
  + deltas: Prune deltas when the corresponding "to" commit
    vanishes.
  + repo: Add a new iterator traversal API for commits.
  + deltas: Search for similar objects (possibly renamed across
    directories).
  + tests: Restore accidentally deleted Makefile bit.
  + libostree: set directory mtimes to 0 on checkout.
  + repo: Check for OSTREE_REPO in ostree_repo_new_default().
  + tests: do not run tests/test-rollsum as part of make check.
  + Use libglnx.
  + deploy: Also look for /usr/lib/os-release.
  + checkout: Drop internal use of GFile *.
  + libglnx: Use git.gnome.org's copy.
  + repo: Port APIs used by prune to fd-relative *at calls.
  + Add explicit zlib dependency.
  + tests: Move test gpg keyring into writable tmpdir.
  + ostree-repo-traverse.c: Fix documentation parameter name.
  + Fix GObject introspection annotation.
  + ostree-repo-static-delta-processing: initialize "modev".
  + build: build libbupsplit separately.
  + prepare-root: Move /sysroot instead of unmounting it.
  + repo: detached sigs: Use error prefixing instead of
    overwriting.
  + ostree: Add gpg-sign command.
  + gpg: Remove _ostree_gpg_verifier_set_homedir().
  + configure.ac: Bump GLib requirement to 2.40.
  + libotutil: Remove ot_variant_new_from_bytes().
  + libotutil: Allow no variant in
    ot_util_variant_builder_from_variant().
  + core: Add definitions for GPG signature metadata.
  + core: Fix duplication bug in
    _ostree_detached_metadata_append_gpg_sig().
  + deploy: Use glnx file copy code.
  + repo: Drop internal GFile* API helper.
  + repo: Port hardlink-scanning code to fd-relative calls.
  + Add bsdiff submodule.
  + Add bsdiff support to deltas.
  + static-delta: increase threshold for rollsum to 50%%.
  + tests: add test for bsdiff.
  + autogen.sh: replace all $(libbsdiff_srcpath) and
    $(libglnx_srcpath).
  + Fix "make syntax-check" failures.
  + Makefile.dist-packaging: fix make rpm with submodules.
  + static-delta: Add --disable-bsdiff option.
  + ostree_repo_static_delta_generate: add new param "verbose".
  + tests: enforce ${CMD_PREFIX} on all ostree processes.
  + tests: Remove some duplications from Makefile-tests.am.
  + deltas: Gather statistics on total number rollsum'd and
    bsdiff'd.
  + deltas: Use mmap() instead of copying input file.
  + commit: Add missing (allow-none) in write_ref_immediate().
  + repo: Fix assertion to allow NULL options.
  + tests: add tests for mutable tree.
  + gpg: Rewrite OstreeGpgVerifier to use GPGME.
  + OstreeGpgVerifier: Take the signature as a GBytes.
  + src: drop some dead assignments.
  + ostree-repo-refs: Drop unused function "parse_rev_file".
  + ot_keyfile_copy_group: return FALSE on invalid inputs.
  + keyfile-utils: add tests.
  + tests: add test for test-ot-opt-utils.
  + libotutil: remove ot-waitable-queue.
  + src: Move ot-tool-util from ostree/ to libotutil/.
  + src: Drop unused argument "value" from ot_parse_boolean.
  + tests: Add tests for test-ot-tool-util.
  + sysroot: Read some bootloader state with fd-relative API.
  + sysroot: Read the bootloader configuration with fd-relative
    API.
  + sysroot: Make origin parsing code fd-relative.
  + glnx: Update.
  + ostree-prepare-root: log informational messages to stdout.
  + sysroot: Drop unnecessary new sysroot object.
  + deployment: Add an API to get relative origin path.
  + sysroot: Port some deployment reading code to fd-relative APIs.
  + README.md: Note make check.
  + configure.ac: Make gpgme a hard dependency.
  + build: Use both pkg-config and AM_PATH_GPGME.
  + repo: Delete .commitmeta file on empty metadata.
  + ostree-repo.c: fix typo.
  + OstreeGpgVerifier: Don't add trustdb.gpg to the keyring list.
  + OstreeGpgVerifier: Take the signed data as a GBytes.
  + fsck: Fix object count output.
  + gpg: Add OstreeGpgVerifyResult.
  + repo: Add ostree_repo_verify_commit_ext().
  + repo: Reject duplicate signatures when signing commit.
  + gpg-sign: Add a --delete option to delete signatures.
  + show: Print a blurb for each signature on a commit.
  + tests: Update test-gpg-signed-commit.sh.
  + gpg: Link to GPGME bug about GPGME_SIGSUM_KEY_REVOKED.
  + gpg: Regenerate test data for test-gpg-verify-result.
  + Fix build failure on g_autoptr(gchar) with glib master.
  + build: ostree-gpg-verify-result.h is a public header, install
    it.
  + libglnx: Update to latest.
  + gpg-sign: Update man page for --delete option.
  + Fix build with !HAVE_LIBSOUP.
  + gpg-sign: Add missing NULL terminator in options.
  + Release 2015.4.
  + Add ostree_repo_is_writable().
  + Add ostree_ensure_repo_writable().
  + Check repo permission prior to attempting to modify it.
  + tests: Add a test case for unwritable repos.
  + Add OstreeAdminBuiltinFlags for admin commands.
  + Add OSTREE_ADMIN_BUILTIN_FLAG_SUPERUSER.
  + bsdiff: change submodule location.
  + core: Fix possible crash in ostree_mutable_tree_walk().
  + Include ostree-gpg-verify-result.h in ostree.h.
  + main: Only verify SUPERUSER flag if using default sysroot.
  + build: Use glibc's xattr support instead of requiring libattr.
  + build: Drop libattr from the spec file.
  + tests/basic-test.sh: enable repo-noperm test only for non-root
    user.
  + src/ostree/ot-main.c: drop empty newline at end of file.
  + build: exclude .sig files from syntax-check.
  + tests: skip test-commit-sign.sh when not root.
  + dist-packaging: Don't delete 91-ostree.preset, do clean old
    rpms/sources.
  + tests: Missing linker flags for test-rollsum.
  + core: Actually allow none in ostree_parse_refspec().
  + tests: Verify that the pull error was from interruption.
  + pull: Handle remote web server not honoring range requests.
  + ostree_repo_checkout_tree_at: New API for checkouts.
  + Release 2015.5.
- Add libcap-devel BuildRequires.
* Thu Feb 19 2015 dimstar@opensuse.org
- Initial package, version 2015.3.
